/*******************************************************************************
* File Name: EDW555_v_1_1_VDAC8_1_PM.c  
* Version 1.90
*
* Description:
*  This file provides the power management source code to API for the
*  VDAC8.  
*
* Note:
*  None
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "EDW555_v_1_1_VDAC8_1.h"

static EDW555_v_1_1_VDAC8_1_backupStruct EDW555_v_1_1_VDAC8_1_backup;


/*******************************************************************************
* Function Name: EDW555_v_1_1_VDAC8_1_SaveConfig
********************************************************************************
* Summary:
*  Save the current user configuration
*
* Parameters:  
*  void  
*
* Return: 
*  void
*
*******************************************************************************/
void EDW555_v_1_1_VDAC8_1_SaveConfig(void) 
{
    if (!((EDW555_v_1_1_VDAC8_1_CR1 & EDW555_v_1_1_VDAC8_1_SRC_MASK) == EDW555_v_1_1_VDAC8_1_SRC_UDB))
    {
        EDW555_v_1_1_VDAC8_1_backup.data_value = EDW555_v_1_1_VDAC8_1_Data;
    }
}


/*******************************************************************************
* Function Name: EDW555_v_1_1_VDAC8_1_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the current user configuration.
*
* Parameters:  
*  void
*
* Return: 
*  void
*
*******************************************************************************/
void EDW555_v_1_1_VDAC8_1_RestoreConfig(void) 
{
    if (!((EDW555_v_1_1_VDAC8_1_CR1 & EDW555_v_1_1_VDAC8_1_SRC_MASK) == EDW555_v_1_1_VDAC8_1_SRC_UDB))
    {
        if((EDW555_v_1_1_VDAC8_1_Strobe & EDW555_v_1_1_VDAC8_1_STRB_MASK) == EDW555_v_1_1_VDAC8_1_STRB_EN)
        {
            EDW555_v_1_1_VDAC8_1_Strobe &= (uint8)(~EDW555_v_1_1_VDAC8_1_STRB_MASK);
            EDW555_v_1_1_VDAC8_1_Data = EDW555_v_1_1_VDAC8_1_backup.data_value;
            EDW555_v_1_1_VDAC8_1_Strobe |= EDW555_v_1_1_VDAC8_1_STRB_EN;
        }
        else
        {
            EDW555_v_1_1_VDAC8_1_Data = EDW555_v_1_1_VDAC8_1_backup.data_value;
        }
    }
}


/*******************************************************************************
* Function Name: EDW555_v_1_1_VDAC8_1_Sleep
********************************************************************************
* Summary:
*  Stop and Save the user configuration
*
* Parameters:  
*  void:  
*
* Return: 
*  void
*
* Global variables:
*  EDW555_v_1_1_VDAC8_1_backup.enableState:  Is modified depending on the enable 
*  state  of the block before entering sleep mode.
*
*******************************************************************************/
void EDW555_v_1_1_VDAC8_1_Sleep(void) 
{
    /* Save VDAC8's enable state */    
    if(EDW555_v_1_1_VDAC8_1_ACT_PWR_EN == (EDW555_v_1_1_VDAC8_1_PWRMGR & EDW555_v_1_1_VDAC8_1_ACT_PWR_EN))
    {
        /* VDAC8 is enabled */
        EDW555_v_1_1_VDAC8_1_backup.enableState = 1u;
    }
    else
    {
        /* VDAC8 is disabled */
        EDW555_v_1_1_VDAC8_1_backup.enableState = 0u;
    }
    
    EDW555_v_1_1_VDAC8_1_Stop();
    EDW555_v_1_1_VDAC8_1_SaveConfig();
}


/*******************************************************************************
* Function Name: EDW555_v_1_1_VDAC8_1_Wakeup
********************************************************************************
*
* Summary:
*  Restores and enables the user configuration
*  
* Parameters:  
*  void
*
* Return: 
*  void
*
* Global variables:
*  EDW555_v_1_1_VDAC8_1_backup.enableState:  Is used to restore the enable state of 
*  block on wakeup from sleep mode.
*
*******************************************************************************/
void EDW555_v_1_1_VDAC8_1_Wakeup(void) 
{
    EDW555_v_1_1_VDAC8_1_RestoreConfig();
    
    if(EDW555_v_1_1_VDAC8_1_backup.enableState == 1u)
    {
        /* Enable VDAC8's operation */
        EDW555_v_1_1_VDAC8_1_Enable();

        /* Restore the data register */
        EDW555_v_1_1_VDAC8_1_SetValue(EDW555_v_1_1_VDAC8_1_Data);
    } /* Do nothing if VDAC8 was disabled before */    
}


/* [] END OF FILE */
